pub struct ContainerdDetector;Expand description
Helper type for detecting if containerd is available.
Implementations
Sourceimpl ContainerdDetector
impl ContainerdDetector
Sourcepub fn detect_grpc_socket_path(socket_path: Option<PathBuf>) -> Option<PathBuf>
pub fn detect_grpc_socket_path(socket_path: Option<PathBuf>) -> Option<PathBuf>
Tries to detect the containerd gRPC socket path.
If socket_path is given, that path is used. Otherwise, well-known paths are probed for a Unix domain socket.
Either way, None is returned unless the resulting path refers to containerd.