pub struct FeatureDetector { /* private fields */ }Expand description
Detects workload features.
The feature detector is used to determine which features are present in the workload, such as if the application is running in a Kubernetes environment or directly on Docker. This information is used to drive the collection of workload metadata that powers entity tagging.
FeatureDetector can be used in an automatic detection mode, where it will attempt to detect all features that are
present, or it can be used to assert that a specific feature is present for scenarios where the feature is required,
and the workload is already known upfront.
Implementations
Sourceimpl FeatureDetector
impl FeatureDetector
Sourcepub fn automatic(containerd_socket_path: Option<PathBuf>) -> Self
pub fn automatic(containerd_socket_path: Option<PathBuf>) -> Self
Creates a new FeatureDetector that checks for all possible features.
If containerd_socket_path is given, that path is used for containerd detection. Otherwise, well-known paths
are probed.
Sourcepub fn for_feature(
containerd_socket_path: Option<PathBuf>,
feature_mask: Feature,
) -> Self
pub fn for_feature( containerd_socket_path: Option<PathBuf>, feature_mask: Feature, ) -> Self
Creates a new FeatureDetector that checks for the given features.
Multiple features can be checked for by combining the feature variants in a bitwise OR fashion.
If containerd_socket_path is given, that path is used for containerd detection. Otherwise, well-known paths
are probed.
Sourcepub fn is_feature_available(&self, feature: Feature) -> bool
pub fn is_feature_available(&self, feature: Feature) -> bool
Checks if the given feature was detected and is available.